# Reporting Security Issues

If you think you have found a security vulnerability, please send a report to security@datahub.com. This address can be used for all of DataHub’s open source and commercial products (including but not limited to DataHub Core and DataHub Cloud). We can accept only vulnerability reports at this address.

It's not mandatory, but if you'd like to encrypt your message to us; please use our PGP key. The key fingerprint is:

61C8 635F 856A 97AA 90D2 E1D9 EBD4 FB71 D997 8918

The key is available from keys.openpgp.org.

DataHub will send you a response indicating the next steps in handling your report. After the initial reply to your report, the security team will keep you informed of the progress towards a fix and full announcement, and may ask for additional information or guidance.

Important: We ask you to not disclose the vulnerability before it have been fixed and announced, unless you received a response from the DataHub security team that you can do so.

# Security announcements

We maintain Security Advisories on the DataHub project GitHub repository, where we will post a summary, remediation, and mitigation details for any patch containing security fixes.
